#ifndef NT2_INCLUDE_FUNCTIONS_ISINTEGER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISINTEGER_HPP_INCLUDED

#include <nt2/predicates/include/functions/isinteger.hpp>

#endif
